@echo off
rem ********************************************************************************
rem *
rem * CFGRAID.BAT
rem *
rem * This file controls the RAID configuration of supported RAID controllers.
rem *
rem * The CFG_RD environment variable defined and set in usrvars.bat controls
rem * whether this batch file is run or not.
rem *
rem * This batch file is called by runinst.bat.
rem *
rem ********************************************************************************

call loadraid.bat
%RAMDSK%

rem ********************************************************************************
rem * Set variables that control error conditions
rem ********************************************************************************
set E1_PARAM=
set E2_PARAM=
FOR %%i in (y Y) do if %RD_ERR1% == %%i set E1_PARAM=/e1
FOR %%i in (y Y) do if %RD_ERR2% == %%i set E2_PARAM=/e2

rem ********************************************************************************
rem * Determine if defaults should be used, or a policies file should be used
rem ********************************************************************************
if "%RD_FILE%" == "" goto RD_DEF

rem ********************************************************************************
rem * Run PRAID using a policies file
rem ********************************************************************************
if %DPLY_TYPE%==4 %TKDRV%\logevent.exe -c:0 -l:1 -ss:"CFGRAID:  Configuring RAID using %RD_PATH%\%RD_FILE%."

PRAID /f:%RD_PATH%\%RD_FILE% /y /b %E1_PARAM% %E2_PARAM%

if errorlevel 9 goto ERRMISC
if errorlevel 8 goto ERRGATH
if errorlevel 7 goto ERRREST
if errorlevel 6 goto ERRTEMP
if errorlevel 5 goto ERRPOLY
if errorlevel 4 goto ERRCOMM
if errorlevel 3 goto ERRDRIVE
if errorlevel 2 goto ERRNRAID
if errorlevel 1 goto ERRNPOLY

rem * Check return code for MSDOS
call PRDERR.BAT

if %PRDERR% == 9 goto ERRMISC
if %PRDERR% == 8 goto ERRGATH
if %PRDERR% == 7 goto ERRREST
if %PRDERR% == 6 goto ERRTEMP
if %PRDERR% == 5 goto ERRPOLY
if %PRDERR% == 4 goto ERRCOMM
if %PRDERR% == 3 goto ERRDRIVE
if %PRDERR% == 2 goto ERRNRAID
if %PRDERR% == 1 goto ERRNPOLY

goto RUN


:RD_DEF
rem ********************************************************************************
rem * Run PRAID using default settings
rem ********************************************************************************
if %DPLY_TYPE%==4 %TKDRV%\logevent.exe -c:0 -l:1 -ss:"CFGRAID:  Configuring RAID using default settings."

PRAID /d /y /b %E1_PARAM% %E2_PARAM%

if errorlevel 9 goto ERRMISC
if errorlevel 8 goto ERRGATH
if errorlevel 7 goto ERRREST
if errorlevel 6 goto ERRTEMP
if errorlevel 5 goto ERRPOLY
if errorlevel 4 goto ERRCOMM
if errorlevel 3 goto ERRDRIVE
if errorlevel 2 goto ERRNRAID
if errorlevel 1 goto ERRNPOLY

rem * Check return code for MSDOS
call PRDERR.BAT

if %PRDERR% == 9 goto ERRMISC
if %PRDERR% == 8 goto ERRGATH
if %PRDERR% == 7 goto ERRREST
if %PRDERR% == 6 goto ERRTEMP
if %PRDERR% == 5 goto ERRPOLY
if %PRDERR% == 4 goto ERRCOMM
if %PRDERR% == 3 goto ERRDRIVE
if %PRDERR% == 2 goto ERRNRAID
if %PRDERR% == 1 goto ERRNPOLY

goto RUN

:RUN
rem ********************************************************************************
rem * Run the output script file if there were RAID controllers in the system
rem ********************************************************************************
set PRDERR=0
call PRAIDOUT.BAT

if %PRDERR% == 0 goto ENDSTEPS
goto ERRRUN


:ERRMISC
rem ********************************************************************************
rem * Error -- Miscellaneous error.
rem ********************************************************************************
set MSG=There was an error running the PRAID utility.
echo %MSG%
echo.

if not %DPLY_TYPE%==4 goto ERROR
%TKDRV%\logevent.exe -c:2 -l:2 -ss:"CFGRAID:  %MSG%"
goto ERROR


:ERRGATH
rem ********************************************************************************
rem * Error -- Could not gather information from the controller.
rem ********************************************************************************
set MSG=Could not gather RAID information from a supported controller.
echo %MSG%
echo.

if not %DPLY_TYPE%==4 goto ERROR
%TKDRV%\logevent.exe -c:2 -l:2 -ss:"CFGRAID:  %MSG%"
goto ERROR

:ERRREST
rem ********************************************************************************
rem * Error -- Could not restore default settings on one or more controllers.
rem ********************************************************************************
set MSG=Could not restore factory-default settings on one or more controllers.
echo %MSG%
echo.

if not %DPLY_TYPE%==4 goto ERROR
%TKDRV%\logevent.exe -c:2 -l:2 -ss:"CFGRAID:  %MSG%"
goto ERROR


:ERRTEMP
rem ********************************************************************************
rem * Error -- Could not write to temp space.
rem ********************************************************************************
set MSG=Could not write to temp space.
echo %MSG%
echo.

if not %DPLY_TYPE%==4 goto ERROR
%TKDRV%\logevent.exe -c:2 -l:2 -ss:"CFGRAID:  %MSG%"
goto ERROR


:ERRPOLY
rem ********************************************************************************
rem * Error -- policies file syntax error.
rem ********************************************************************************
set MSG=Policies file does not exist or syntax error in policies file.
echo %MSG%
echo.

if not %DPLY_TYPE%==4 goto ERROR
%TKDRV%\logevent.exe -c:2 -l:2 -ss:"CFGRAID:  %MSG%"
goto ERROR


:ERRCOMM
rem ********************************************************************************
rem * Error -- command line parameters incorrect.
rem ********************************************************************************
set MSG=Command-line syntax error calling PRAID.
echo %MSG%
echo.

if not %DPLY_TYPE%==4 goto ERROR
%TKDRV%\logevent.exe -c:2 -l:2 -ss:"CFGRAID:  %MSG%"
goto ERROR


:ERRDRIVE
rem ********************************************************************************
rem * Error -- no drives attached to one or more controllers
rem ********************************************************************************
set MSG=No drives attached to one or more controllers.
echo %MSG%
echo.

if not %DPLY_TYPE%==4 goto ERROR
%TKDRV%\logevent.exe -c:2 -l:2 -ss:"CFGRAID:  %MSG%"
goto ERROR


:ERRNRAID
rem ********************************************************************************
rem * Error -- no RAID controllers found
rem ********************************************************************************
set MSG=Can not find a supported RAID controller to capture. 
echo %MSG%
echo.

if not %DPLY_TYPE%==4 goto ERROR
%TKDRV%\logevent.exe -c:2 -l:2 -ss:"CFGRAID:  %MSG%"
goto ERROR


:ERRRUN
rem ********************************************************************************
rem * Error -- Configuration error.
rem ********************************************************************************
set MSG=There was an error configuring one or more controllers
echo %MSG%
echo.

if not %DPLY_TYPE%==4 goto ERROR
%TKDRV%\logevent.exe -c:2 -l:2 -ss:"CFGRAID:  %MSG%"
goto ERROR    


:ENDSTEPS
rem ********************************************************************************
rem * If not doing a standard Toolkit installation, jump
rem * DPLY_TYPE=
rem *   4 - Deployment using Altiris(R) Deployment Solution.
rem *   5 - Deployment using Microsoft(R) Automated Deployment Services.
rem ********************************************************************************
echo.
echo RAID configuration complete.  Saving status and rebooting server.
if %DPLY_TYPE%==4 goto ALTSTAT0
if %DPLY_TYPE%==5 goto RAIDBOOT

savestat.exe /set2=50 > nul

rem ********************************************************************************
rem * Check for errors: SAVESTAT.EXE
rem ********************************************************************************
if not errorlevel 255 goto RAIDBOOT
echo An error occurred during writing to persistent storage.
echo.
goto ERROR


:RAIDBOOT
rem ********************************************************************************
rem * If a configuration was done, we need to reboot the system before continuing
rem * the process.
rem ********************************************************************************
sleep 15
reboot.com

goto END



:ERROR
rem ********************************************************************************
rem * Handle errors.
rem ********************************************************************************
echo.
echo Encountered an error configuring the RAID controllers in "cfgraid.bat".

if %DPLY_TYPE%==4 goto ALTSTAT1
if %DPLY_TYPE%==5 goto ADSSTAT

savestat.exe /set2=251 > nul
goto END


:ADSSTAT
rem ********************************************************************************
rem * ADS jump
rem ********************************************************************************
goto END


:ALTSTAT0
rem ********************************************************************************
rem * Update Altiris with necessary status
rem ********************************************************************************
echo Updating Altiris status: Good

%TKDRV%\logevent.exe -c:0 -l:1 -ss:"CFGRAID: Completed successfully."
goto END

rem Reset to root of Toolkit drive
%TKDRV%
cd \

goto END


:ALTSTAT1
rem ********************************************************************************
rem * Update Altiris with necessary status
rem ********************************************************************************
echo Updating Altiris status: Error
%TKDRV%\logevent.exe -c:251 -l:3 -ss:"CFGRAID:  Encountered an error."

rem Reset to root of Toolkit drive
%TKDRV%
cd \

rem Reset persistent storage
savestat.exe /reset > nul
goto END


:END
rem ********************************************************************************
rem * Finished.
rem ********************************************************************************
%TKDRV%

