@echo off
rem ********************************************************************************
rem *
rem * HWDET.BAT
rem *
rem * This file executes hwdetect.exe to determine what types/numbers of
rem * either RAID adapters or fibre adapter found in the server.
rem *
rem * It sets the following environment variables for ServeRAID:
rem *    NM_SR  Number of ServRAID 4H, 4Lx, 4Mx, 4M, 4L, 5i, 6M, 6i
rem *    NM_TT  Number of ServRAID t-type
rem *    NM_EA  Number of ServRAID e-type SATA
rem *    NM_ES  Number of ServRAID e-type SCSI
rem *    NM_IS  Number of Integrated SCSI with RAID capabilities
rem *    NM_ID  Number of IDE RAID
rem *
rem * It sets the following environment variables for Fibre adapters:
rem *    NM_F2  Found an IBM FAStT Host Adapter BIOS
rem *    NM_F3  Found an IBM FAStT FC-133 Host Bus Adapter BIOS
rem *    NM_FB  Found an IBM HS20 Fibre Channel Expansion Card BIOS
rem *
rem * This batch file is called by either cfgraid.bat or cfgfibre.bat
rem *
rem ********************************************************************************


rem ********************************************************************************
rem * Determine how to run the Hardware detect, ServeRAID or Fibre
rem ********************************************************************************
if "%1"== "" goto HW_SR
if %1 == 1 goto HW_SR
if %1 == 2 goto HW_FIB


:HW_SR
rem ********************************************************************************
rem * Determine if there are any IBM ServeRAID adapters found - max=16
rem ********************************************************************************
set NM_SR=0
set NM_TT=0
set NM_EA=0
set NM_ES=0
set NM_IS=0
set NM_ID=0

rem *** ServeRAID 4H
hwdetect /vid:1014 /did:002E
for %%i in (1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16) do if errorlevel %%i set NM_SR=%%i

rem *** ServeRAID 4Lx  4Mx   4M  4L  5i
hwdetect /vid:1014 /did:01BD /ADD:%NM_SR%
for %%i in (1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16) do if errorlevel %%i set NM_SR=%%i

rem *** ServeRAID 6M    6i
hwdetect /vid:9005 /did:0250 /ADD:%NM_SR%
for %%i in (1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16) do if errorlevel %%i set NM_SR=%%i

rem ********************************************************************************
rem * Determine if there are any IBM ServeRAID t-type adapters found - max=16
rem ********************************************************************************
rem *** ServeRAID 7t
hwdetect /vid:9005 /did:0285
for %%i in (1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16) do if errorlevel %%i set NM_TT=%%i

rem ********************************************************************************
rem * Determine if there are any IBM ServeRAID e-type SATA found - max=2
rem ********************************************************************************
rem *** ServeRAID 7E SATA
hwdetect /vid:8086 /did:25B0
for %%i in (1 2) do if errorlevel %%i set NM_EA=%%i

hwdetect /vid:8086 /did:24DF  /ADD:%NM_EA%
for %%i in (1 2) do if errorlevel %%i set NM_EA=%%i

rem ********************************************************************************
rem * Determine if there are any IBM ServeRAID e-type SCSI found - max=1
rem ********************************************************************************

rem *** ServeRAID 7E SCSI
hwdetect /vid:9005 /did:808F
for %%i in (1 2) do if errorlevel %%i set NM_ES=%%i

hwdetect /vid:9005 /did:809D  /ADD:%NM_ES%
for %%i in (1 2) do if errorlevel %%i set NM_ES=%%i

rem ********************************************************************************
rem * Determine if there are any Integrated SCSI with RAID capabilities controllers
rem * found - max=2
rem ********************************************************************************

rem *** Integrated SCSI with RAID capabilities controller(s)
hwdetect /vid:1000 /did:0030
for %%i in (1 2) do if errorlevel %%i set NM_IS=%%i


rem ********************************************************************************
rem * Determine if there are any IDE RAID controllers found  -  max=1
rem ********************************************************************************

rem *** IDE RAID controller
hwdetect /vid:1166 /did:0213 /svid:1014 /sdid:0213
if errorlevel 1 set NM_ID=1

goto END

    
:HW_FIB    
rem ********************************************************************************
rem * Determine if there are any fibre adapters found - max=1 (of each)
rem ********************************************************************************
set NM_F2=0
set NM_F3=0
set NM_FB=0

rem *** IBM FAStT Host Adapter BIOS -- 1077 2200
hwdetect /vid:1077 /did:2200
if errorlevel 1 set NM_F2=1

rem *** IBM FAStT FC-133 Host Bus Adapter BIOS -- 1077 2312
hwdetect /vid:1077 /did:2312 /svid:1077
if errorlevel 1 set NM_F3=1

rem *** IBM HS20 Fibre Channel Expansion Card BIOS -- 1077 2312 1014
hwdetect /vid:1077 /did:2312 /svid:1014
if errorlevel 1 set NM_FB=1

    
:END
